@@ -7,9 +7,9 @@
 
 ;; URL: https://codeberg.org/ideasman42/emacs-sidecar-locals
 ;; Keywords: convenience
-;; Package-Version: 20251126.347
-;; Package-Revision: 33c52d010227
-;; Package-Requires: ((emacs "27.1"))
+;; Package-Version: 20260108.324
+;; Package-Revision: 0c969ab64bee
+;; Package-Requires: ((emacs "28.1"))
 
 ;;; Commentary:
 
@@ -28,7 +28,7 @@
 ;;   and avoid changes to the global state in a way that might cause unexpected behavior.
 ;;
 
-;;; Usage
+;;; Usage:
 
 ;;
 ;; Write the following code to your .emacs file:
@@ -57,11 +57,11 @@
 
 (defcustom sidecar-locals-paths-allow nil
   "List of trusted paths (must contain trailing slashes)."
-  :type '(repeat string))
+  :type '(repeat directory))
 
 (defcustom sidecar-locals-paths-deny nil
   "List of untrusted paths (must contain trailing slashes)."
-  :type '(repeat string))
+  :type '(repeat directory))
 
 (defcustom sidecar-locals-ignore-modes nil
   "List of major-modes where `sidecar-locals' won't be used."
@@ -76,7 +76,6 @@ check this buffer.")
 
 (defcustom sidecar-locals-dir-name ".sidecar-locals"
   "The directory name to discover sidecar-locals in."
-
   :type 'string)
 
 
@@ -221,7 +220,7 @@ This is done without adjusting trailing slashes or following links."
 ;; Internal Implementation Functions
 
 (defun sidecar-locals--trusted-p (dir path-trust)
-  "Check if DIR should be trusted, this includes any of it's parent directories.
+  "Check if DIR should be trusted, this includes any of its parent directories.
 PATH-TRUST is cons cell: (paths-deny . paths-allow)
 derived from `sidecar-locals-paths-deny' & `sidecar-locals-paths-allow'.
 
@@ -268,13 +267,12 @@ Returns: 1 to trust, -1 is untrusted, nil is untrusted and not configured."
      ((eq trust -1)
       nil)
      (t
-      (progn
-        (message
-         (concat
-          "sidecar-locals: un-trusted path %S, "
-          "add to `sidecar-locals-paths-allow' or `sidecar-locals-paths-deny' to silence this message.")
-         dir)
-        nil)))))
+      (message
+       (concat
+        "sidecar-locals: un-trusted path %S, "
+        "add to `sidecar-locals-paths-allow' or `sidecar-locals-paths-deny' to silence this message.")
+       dir)
+      nil))))
 
 (defsubst sidecar-locals--root-impl (path beg end)
   "Internal function to extract the root from PATH removing BEG & END range."
@@ -373,7 +371,7 @@ When NO-TEST is non-nil checking for existing paths is disabled."
           (unless (or no-test (sidecar-locals--safe-file-exists-p dir-iter))
             ;; Exit loop.
             ;; There is no need to continue past a missing directory,
-            ;; as all it's subdirectories will be missing too.
+            ;; as all its subdirectories will be missing too.
             (setq dir-tail-list nil))))
       ;; Ensure stale values are never used.
       (setq sidecar-locals--root nil))))
@@ -384,7 +382,7 @@ When NO-TEST is non-nil checking for existing paths is disabled."
   (and
    ;; Not in the mini-buffer.
    (null (minibufferp))
-   ;; Not a special mode (package list, tabulated data ... etc)
+   ;; Not a special mode (package list, tabulated data, etc.)
    ;; Instead the buffer is likely derived from `text-mode' or `prog-mode'.
    (null (derived-mode-p 'special-mode))
    ;; Not explicitly ignored.
@@ -410,7 +408,7 @@ When NO-TEST is non-nil checking for existing paths is disabled."
      ;; Errors here cause the file not to open,
      ;; report them as messages instead.
      (condition-case-unless-debug err
-         (load filepath :nomessage t)
+         (load filepath nil t)
        (error
         (message "sidecar-locals: error %s in %S" (error-message-string err) filepath))))
    ;; Only run for files that exist.
@@ -542,7 +540,7 @@ When NO-TEST is non-nil checking for existing paths is disabled."
          (sidecar-locals--buffer-insert-filepath filepath map)))
      t)
     (pop-to-buffer buf)
-    (view-mode-enter nil (lambda (buf) (kill-buffer buf)))))
+    (view-mode-enter nil #'kill-buffer)))
 
 
 ;; ---------------------------------------------------------------------------
@@ -581,8 +579,8 @@ This creates a buffer with links that visit that file."
   "Turn on option `sidecar-locals-mode' globally."
   (declare (important-return-value nil))
   (setq sidecar-locals--last-checked-paths nil)
-  (add-hook 'after-set-visited-file-name-hook #'sidecar-locals-hook nil nil)
-  (add-hook 'find-file-hook #'sidecar-locals-hook nil nil)
+  (add-hook 'after-set-visited-file-name-hook #'sidecar-locals-hook)
+  (add-hook 'find-file-hook #'sidecar-locals-hook)
 
   (advice-add
    'hack-dir-local-variables-non-file-buffer
@@ -592,8 +590,8 @@ This creates a buffer with links that visit that file."
   "Turn off option `sidecar-locals-mode' globally."
   (declare (important-return-value nil))
   (setq sidecar-locals--last-checked-paths nil)
-  (remove-hook 'after-set-visited-file-name-hook #'sidecar-locals-hook nil)
-  (remove-hook 'find-file-hook #'sidecar-locals-hook nil)
+  (remove-hook 'after-set-visited-file-name-hook #'sidecar-locals-hook)
+  (remove-hook 'find-file-hook #'sidecar-locals-hook)
 
   (advice-remove
    'hack-dir-local-variables-non-file-buffer
